@@ -265,3 +265,29 @@ class SWAS:
         )
         return json.dumps(client.renew_instance(renew_instance_request).body.to_map())
 
+
+    def resetSystem(self, instance_id, image_id=''):
+        """[重置系统]https://next.api.aliyun.com/document/SWAS-OPEN/2020-06-01/ResetSystem
+
+        Args:
+            instance_id ([str]): [指定的轻量应用服务器的实例ID]
+            image_id ([str]): [目标镜像ID。如果不输入目标镜像ID，默认为重置当前镜像。]
+
+        Returns:
+            [json]: [json response]
+        """
+
+        client = SWAS.create_client(self.access_key_id, self.access_key_secret)
+        if len(image_id) > 0:
+            reset_system_request = swas__open20200601_models.ResetSystemRequest(
+                instance_id=instance_id,
+                region_id=self.region_id,
+                image_id=image_id
+            )
+        else:
+            reset_system_request = swas__open20200601_models.ResetSystemRequest(
+            instance_id=instance_id,
+            region_id=self.region_id
+        )
+        return json.dumps(client.reset_system(reset_system_request).body.to_map())
+
